@@ -30,7 +30,6 @@ from evm_trace import CallTreeNode, CallType, TraceFrame, get_calltree_from_geth
 from hexbytes import HexBytes
 from web3 import HTTPProvider, Web3
 from web3.gas_strategies.rpc import rpc_gas_price_strategy
-from web3.middleware import geth_poa_middleware
 
 from .exceptions import HardhatNotInstalledError, HardhatProviderError, HardhatSubprocessError
 
@@ -241,7 +240,7 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
             return
 
         self._web3 = Web3(HTTPProvider(self.uri, request_kwargs={"timeout": self.timeout}))
-        if not self._web3.isConnected():
+        if not self._web3.is_connected():
             self._web3 = None
             return
 
@@ -361,7 +360,7 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
             yield TraceFrame(**frame)
 
     def get_call_tree(self, txn_hash: str) -> CallTreeNode:
-        receipt = self.get_receipt(txn_hash)
+        receipt = self.chain_manager.get_receipt(txn_hash)
         root_node_kwargs = {
             "gas_cost": receipt.gas_used,
             "gas_limit": receipt.gas_limit,
@@ -474,14 +473,9 @@ class HardhatForkProvider(HardhatProvider):
 
         # Verify that we're connected to a Hardhat node with mainnet-fork mode.
         self._upstream_provider.connect()
-        upstream_chain_id = self._upstream_provider.chain_id
         upstream_genesis_block_hash = self._upstream_provider.get_block(0).hash
         self._upstream_provider.disconnect()
 
-        # If upstream network is rinkeby, goerli, or kovan (PoA test-nets)
-        if upstream_chain_id in (4, 5, 42):
-            self._web3.middleware_onion.inject(geth_poa_middleware, layer=0)
-
         if self.get_block(0).hash != upstream_genesis_block_hash:
             logger.warning(
                 "Upstream network has mismatching genesis block. "
